@@ -29,6 +29,7 @@ import setzer.document.source_buffer.source_buffer as source_buffer
 import setzer.document.spellchecker.spellchecker as spellchecker
 from setzer.helpers.observable import Observable
 from setzer.app.service_locator import ServiceLocator
+from setzer.helpers.timer import timer
 
 
 class Document(Observable):
@@ -45,10 +46,7 @@ class Document(Observable):
         self.last_activated = 0
         self.dark_mode = False
         self.is_master = False
-        self.can_sync = False
 
-        self.parser = None
-        self.build_system = None
         self.source_buffer = source_buffer.SourceBuffer(self)
 
         self.view = document_view.DocumentView(self, self.source_buffer.view)
@@ -132,14 +130,14 @@ class Document(Observable):
     def save_to_disk(self):
         if self.filename == None: return False
         if self.get_buffer() == None: return False
-        else:
-            text = self.get_text()
-            if text != None:
-                with open(self.filename, 'w') as f:
-                    f.write(text)
-                self.update_save_date()
-                self.deleted_on_disk_dialog_shown_after_last_save = False
-                self.get_buffer().set_modified(False)
+
+        text = self.get_text()
+        if text != None:
+            with open(self.filename, 'w') as f:
+                f.write(text)
+            self.update_save_date()
+            self.deleted_on_disk_dialog_shown_after_last_save = False
+            self.get_buffer().set_modified(False)
 
     def update_save_date(self):
         self.save_date = os.path.getmtime(self.filename)
@@ -153,6 +151,7 @@ class Document(Observable):
     def initially_set_text(self, text):
         self.get_buffer().initially_set_text(text)
 
+    #@timer
     def get_text(self):
         return self.get_buffer().get_all_text()
 
@@ -174,9 +173,6 @@ class Document(Observable):
     def is_empty(self):
         return self.source_buffer.is_empty()
 
-    def set_initial_folded_regions(self, folded_regions):
-        self.code_folding.set_initial_folded_regions(folded_regions)
-        
     def place_cursor(self, line_number, offset=0):
         self.get_buffer().place_cursor_and_scroll(line_number, offset)
 
@@ -201,18 +197,6 @@ class Document(Observable):
     def insert_before_document_end(self, text):
         self.get_buffer().insert_before_document_end(text)
 
-    def add_packages(self, packages):
-        self.get_buffer().add_packages(packages)
-
-    def get_packages(self):
-        return self.parser.symbols['packages']
-
-    def get_package_details(self):
-        return self.parser.symbols['packages_detailed']
-
-    def remove_packages(self, packages):
-        self.get_buffer().remove_packages(packages)
-
     def insert_text(self, line_number, offset, text, indent_lines=True):
         self.get_buffer().insert_text(line_number, offset, text, indent_lines)
 
