@@ -31,7 +31,7 @@ import setzer.workspace.help_panel.help_panel as help_panel
 import setzer.workspace.sidebar.sidebar as sidebar
 import setzer.workspace.build_log.build_log as build_log
 import setzer.workspace.headerbar.headerbar_presenter as headerbar_presenter
-import setzer.workspace.document_chooser.document_chooser_presenter as document_chooser_presenter
+import setzer.workspace.document_chooser.document_chooser as document_chooser
 import setzer.workspace.keyboard_shortcuts.shortcuts as shortcuts
 import setzer.workspace.document_switcher.document_switcher as document_switcher
 import setzer.workspace.actions.actions as actions
@@ -77,7 +77,7 @@ class Workspace(Observable):
         self.actions = actions.Actions(self)
         self.presenter = workspace_presenter.WorkspacePresenter(self)
         self.headerbar = headerbar_presenter.HeaderbarPresenter(self)
-        self.document_chooser = document_chooser_presenter.DocumentChooserPresenter(self)
+        self.document_chooser = document_chooser.DocumentChooser(self)
         self.preview_panel = preview_panel_presenter.PreviewPanelPresenter(self)
         self.help_panel = help_panel.HelpPanel(self)
         self.document_switcher = document_switcher.DocumentSwitcher(self)
@@ -115,6 +115,7 @@ class Workspace(Observable):
         if document == self.master_document:
             self.unset_master_document()
         document.state_manager.save_document_state()
+        document.controller.continue_save_date_loop = False
         self.open_documents.remove(document)
         if document.is_latex_document():
             self.open_latex_documents.remove(document)
